@@ -7,8 +7,9 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
 use PHPUnit\Framework\TestCase;
-use PHPUnit\TestFixture\AssertionExample;
 
 class AssertionExampleTest extends TestCase
 {
