@@ -9,12 +9,9 @@
  */
 namespace PHPUnit\TestFixture;
 
-use PHPUnit\Framework\TestCase;
-
-class BeforeClassWithOnlyDataProviderTest extends TestCase
+class BeforeClassWithOnlyDataProviderTest extends \PHPUnit\Framework\TestCase
 {
     public static $setUpBeforeClassWasCalled;
-
     public static $beforeClassWasCalled;
 
     public static function resetProperties(): void
