@@ -13,6 +13,13 @@ use PHPUnit\Framework\TestCase;
 
 class FirstTest extends TestCase
 {
+    public static function provide()
+    {
+        SecondTest::DUMMY;
+
+        return [[true]];
+    }
+
     /**
      * @dataProvider provide
      */
@@ -20,11 +27,4 @@ class FirstTest extends TestCase
     {
         $this->assertTrue(true);
     }
-
-    public function provide()
-    {
-        SecondTest::DUMMY;
-
-        return [[true]];
-    }
 }
