@@ -13,6 +13,14 @@ use PHPUnit\Framework\TestCase;
 
 final class TestWithDifferentSizes extends TestCase
 {
+    public static function provider(): array
+    {
+        return [
+            [false],
+            [true],
+        ];
+    }
+
     public function testWithSizeUnknown(): void
     {
         $this->assertTrue(true);
@@ -65,12 +73,4 @@ final class TestWithDifferentSizes extends TestCase
     {
         $this->assertTrue(true);
     }
-
-    public function provider(): array
-    {
-        return [
-            [false],
-            [true],
-        ];
-    }
 }
