@@ -16,28 +16,7 @@ use PHPUnit\Framework\TestCase;
  */
 final class DataProviderWithNumericDataSetNameAndMetadataWithPlaceholdersTest extends TestCase
 {
-    /**
-     * @dataProvider provider
-     *
-     * @testdox Text from method-level TestDox metadata for successful test with placeholders ($a, $b, $c $d, $e)
-     */
-    public function testSomethingThatWorks(string $a, int $b, float $c, array $d, bool $e): void
-    {
-        $this->assertTrue(true);
-    }
-
-    /**
-     * @dataProvider provider
-     *
-     * @testdox Text from method-level TestDox metadata for failing test with placeholders ($a, $b, $c $d, $e)
-     */
-    public function testSomethingThatDoesNotWork(string $a, int $b, float $c, array $d, bool $e): void
-    {
-        /* @noinspection PhpUnitAssertTrueWithIncompatibleTypeArgumentInspection */
-        $this->assertTrue(false);
-    }
-
-    public function provider(): array
+    public static function provider(): array
     {
         return [
             0 => [
@@ -46,7 +25,29 @@ final class DataProviderWithNumericDataSetNameAndMetadataWithPlaceholdersTest ex
                 0.0,
                 ['key' => 'value'],
                 true,
+                Foo::BAR,
             ],
         ];
     }
+
+    /**
+     * @dataProvider provider
+     *
+     * @testdox Text from method-level TestDox metadata for successful test with placeholders ($a, $b, $c $d, $e, $f)
+     */
+    public function testSomethingThatWorks(string $a, int $b, float $c, array $d, bool $e, Foo $f): void
+    {
+        $this->assertTrue(true);
+    }
+
+    /**
+     * @dataProvider provider
+     *
+     * @testdox Text from method-level TestDox metadata for failing test with placeholders ($a, $b, $c $d, $e, $f)
+     */
+    public function testSomethingThatDoesNotWork(string $a, int $b, float $c, array $d, bool $e, Foo $f): void
+    {
+        /* @noinspection PhpUnitAssertTrueWithIncompatibleTypeArgumentInspection */
+        $this->assertTrue(false);
+    }
 }
