@@ -23,6 +23,7 @@ use function json_encode;
 use function log;
 use function mkdir;
 use function octdec;
+use function PHPUnit\TestFixture\Generator\f;
 use function rmdir;
 use function sys_get_temp_dir;
 use function tempnam;
@@ -49,10 +50,11 @@ use SplObjectStorage;
 use stdClass;
 
 #[CoversClass(Assert::class)]
+#[CoversClass(GeneratorNotSupportedException::class)]
 #[Small]
 final class AssertTest extends TestCase
 {
-    public static function validInvalidJsonDataprovider(): array
+    public static function validInvalidJsonProvider(): array
     {
         return [
             'error syntax in expected JSON' => ['{"Mascott"::}', '{"Mascott" : "Tux"}'],
@@ -220,7 +222,7 @@ final class AssertTest extends TestCase
         $this->assertArrayNotHasKey('bar', $array);
     }
 
-    public function testAssertArrayNotHasKeyPropertlyFailsWithArrayAccessValue(): void
+    public function testAssertArrayNotHasKeyProperlyFailsWithArrayAccessValue(): void
     {
         $array        = new ArrayObject;
         $array['bar'] = 'bar';
@@ -354,14 +356,14 @@ final class AssertTest extends TestCase
     {
         $this->assertXmlFileEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'foo.xml'
+            TEST_FILES_PATH . 'foo.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertXmlFileEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
     }
 
@@ -369,14 +371,14 @@ final class AssertTest extends TestCase
     {
         $this->assertXmlFileNotEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertXmlFileNotEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'foo.xml'
+            TEST_FILES_PATH . 'foo.xml',
         );
     }
 
@@ -384,14 +386,14 @@ final class AssertTest extends TestCase
     {
         $this->assertXmlStringEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'foo.xml')
+            file_get_contents(TEST_FILES_PATH . 'foo.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertXmlStringEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
     }
 
@@ -399,14 +401,14 @@ final class AssertTest extends TestCase
     {
         $this->assertXmlStringNotEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertXmlStringNotEqualsXmlFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'foo.xml')
+            file_get_contents(TEST_FILES_PATH . 'foo.xml'),
         );
     }
 
@@ -617,7 +619,7 @@ XML;
 
         $tempFile = tempnam(
             sys_get_temp_dir(),
-            'unreadable'
+            'unreadable',
         );
 
         chmod($tempFile, octdec('0'));
@@ -792,17 +794,17 @@ XML;
     {
         $this->assertNotSame(
             new stdClass,
-            null
+            null,
         );
 
         $this->assertNotSame(
             null,
-            new stdClass
+            new stdClass,
         );
 
         $this->assertNotSame(
             new stdClass,
-            new stdClass
+            new stdClass,
         );
 
         $o = new stdClass;
@@ -897,8 +899,8 @@ XML;
             'anything',
             $this->logicalAnd(
                 $this->anything(),
-                $this->anything()
-            )
+                $this->anything(),
+            ),
         );
     }
 
@@ -909,8 +911,8 @@ XML;
             'anything',
             $this->logicalOr(
                 $this->anything(),
-                $this->anything()
-            )
+                $this->anything(),
+            ),
         );
     }
 
@@ -921,8 +923,8 @@ XML;
             'anything',
             $this->logicalXor(
                 $this->anything(),
-                $this->logicalNot($this->anything())
-            )
+                $this->logicalNot($this->anything()),
+            ),
         );
     }
 
@@ -1018,7 +1020,7 @@ XML;
     {
         $this->assertThat(
             null,
-            $this->callback(static fn ($other) => true)
+            $this->callback(static fn ($other) => true),
         );
     }
 
@@ -1031,14 +1033,14 @@ XML;
     {
         $this->assertFileEquals(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'foo.xml'
+            TEST_FILES_PATH . 'foo.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertFileEquals(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
     }
 
@@ -1046,14 +1048,14 @@ XML;
     {
         $this->assertFileNotEquals(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertFileNotEquals(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'foo.xml'
+            TEST_FILES_PATH . 'foo.xml',
         );
     }
 
@@ -1061,14 +1063,14 @@ XML;
     {
         $this->assertStringEqualsFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'foo.xml')
+            file_get_contents(TEST_FILES_PATH . 'foo.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertStringEqualsFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
     }
 
@@ -1076,14 +1078,14 @@ XML;
     {
         $this->assertStringEqualsFileIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'fooUppercase.xml')
+            file_get_contents(TEST_FILES_PATH . 'fooUppercase.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertStringEqualsFileIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
     }
 
@@ -1091,14 +1093,14 @@ XML;
     {
         $this->assertStringNotEqualsFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertStringNotEqualsFile(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'foo.xml')
+            file_get_contents(TEST_FILES_PATH . 'foo.xml'),
         );
     }
 
@@ -1106,14 +1108,14 @@ XML;
     {
         $this->assertStringNotEqualsFileIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'bar.xml')
+            file_get_contents(TEST_FILES_PATH . 'bar.xml'),
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertStringNotEqualsFileIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            file_get_contents(TEST_FILES_PATH . 'fooUppercase.xml')
+            file_get_contents(TEST_FILES_PATH . 'fooUppercase.xml'),
         );
     }
 
@@ -1121,14 +1123,14 @@ XML;
     {
         $this->assertFileEqualsIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'fooUppercase.xml'
+            TEST_FILES_PATH . 'fooUppercase.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertFileEqualsIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
     }
 
@@ -1136,14 +1138,14 @@ XML;
     {
         $this->assertFileNotEqualsIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'bar.xml'
+            TEST_FILES_PATH . 'bar.xml',
         );
 
         $this->expectException(AssertionFailedError::class);
 
         $this->assertFileNotEqualsIgnoringCase(
             TEST_FILES_PATH . 'foo.xml',
-            TEST_FILES_PATH . 'fooUppercase.xml'
+            TEST_FILES_PATH . 'fooUppercase.xml',
         );
     }
 
@@ -1240,6 +1242,16 @@ XML;
         $this->assertEmpty(['foo']);
     }
 
+    public function testAssertEmptyGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $actual parameter is not supported');
+
+        $this->assertEmpty($generator);
+    }
+
     public function testAssertNotEmpty(): void
     {
         $this->assertNotEmpty(['foo']);
@@ -1249,6 +1261,16 @@ XML;
         $this->assertNotEmpty([]);
     }
 
+    public function testAssertNotEmptyGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $actual parameter is not supported');
+
+        $this->assertNotEmpty($generator);
+    }
+
     public function testMarkTestIncomplete(): void
     {
         try {
@@ -1284,6 +1306,16 @@ XML;
         $this->assertCount(2, [1, 2, 3]);
     }
 
+    public function testAssertCountGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $haystack parameter is not supported');
+
+        $this->assertCount(0, $generator);
+    }
+
     public function testAssertCountTraversable(): void
     {
         $this->assertCount(2, new ArrayIterator([1, 2]));
@@ -1302,6 +1334,16 @@ XML;
         $this->assertNotCount(2, [1, 2]);
     }
 
+    public function testAssertNotCountGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $haystack parameter is not supported');
+
+        $this->assertNotCount(0, $generator);
+    }
+
     public function testAssertSameSize(): void
     {
         $this->assertSameSize([1, 2], [3, 4]);
@@ -1311,6 +1353,26 @@ XML;
         $this->assertSameSize([1, 2], [1, 2, 3]);
     }
 
+    public function testAssertSameSizeGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $expected parameter is not supported');
+
+        $this->assertSameSize($generator, []);
+    }
+
+    public function testAssertSameSizeGenerator2(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $actual parameter is not supported');
+
+        $this->assertSameSize([], $generator);
+    }
+
     public function testAssertNotSameSize(): void
     {
         $this->assertNotSameSize([1, 2], [1, 2, 3]);
@@ -1320,6 +1382,26 @@ XML;
         $this->assertNotSameSize([1, 2], [3, 4]);
     }
 
+    public function testAssertNotSameSizeGenerator(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $expected parameter is not supported');
+
+        $this->assertNotSameSize($generator, []);
+    }
+
+    public function testAssertNotSameSizeGenerator2(): void
+    {
+        $generator = f();
+
+        $this->expectException(GeneratorNotSupportedException::class);
+        $this->expectExceptionMessage('Passing an argument of type Generator for the $actual parameter is not supported');
+
+        $this->assertNotSameSize([], $generator);
+    }
+
     public function testAssertJson(): void
     {
         $this->assertJson('{}');
@@ -1334,7 +1416,7 @@ XML;
         $this->assertJsonStringEqualsJsonString($expected, $actual, $message);
     }
 
-    #[DataProvider('validInvalidJsonDataprovider')]
+    #[DataProvider('validInvalidJsonProvider')]
     public function testAssertJsonStringEqualsJsonStringErrorRaised(string $expected, string $actual): void
     {
         $this->expectException(AssertionFailedError::class);
@@ -1351,7 +1433,7 @@ XML;
         $this->assertJsonStringNotEqualsJsonString($expected, $actual, $message);
     }
 
-    #[DataProvider('validInvalidJsonDataprovider')]
+    #[DataProvider('validInvalidJsonProvider')]
     public function testAssertJsonStringNotEqualsJsonStringErrorRaised(string $expected, string $actual): void
     {
         $this->expectException(AssertionFailedError::class);
@@ -1379,7 +1461,7 @@ XML;
         } catch (ExpectationFailedException $e) {
             $this->assertEquals(
                 'Failed asserting that \'{"Mascott":"Beastie"}\' matches JSON string "{"Mascott":"Tux"}".',
-                $e->getMessage()
+                $e->getMessage(),
             );
 
             return;
@@ -1848,8 +1930,8 @@ XML;
             true,
             $this->logicalAnd(
                 $this->isTrue(),
-                $this->isTrue()
-            )
+                $this->isTrue(),
+            ),
         );
 
         $this->expectException(AssertionFailedError::class);
@@ -1858,8 +1940,8 @@ XML;
             true,
             $this->logicalAnd(
                 $this->isTrue(),
-                $this->isFalse()
-            )
+                $this->isFalse(),
+            ),
         );
     }
 
@@ -1869,8 +1951,8 @@ XML;
             true,
             $this->logicalOr(
                 $this->isTrue(),
-                $this->isFalse()
-            )
+                $this->isFalse(),
+            ),
         );
 
         $this->expectException(AssertionFailedError::class);
@@ -1879,8 +1961,8 @@ XML;
             true,
             $this->logicalOr(
                 $this->isFalse(),
-                $this->isFalse()
-            )
+                $this->isFalse(),
+            ),
         );
     }
 
@@ -1890,8 +1972,8 @@ XML;
             true,
             $this->logicalXor(
                 $this->isTrue(),
-                $this->isFalse()
-            )
+                $this->isFalse(),
+            ),
         );
 
         $this->expectException(AssertionFailedError::class);
@@ -1900,8 +1982,8 @@ XML;
             true,
             $this->logicalXor(
                 $this->isTrue(),
-                $this->isTrue()
-            )
+                $this->isTrue(),
+            ),
         );
     }
 
@@ -2205,7 +2287,7 @@ XML;
                 new DateTime('2013-03-29T05:13:35-0500'),
             ],
             // Exception
-            //array(new Exception('Exception 1'), new Exception('Exception 2')),
+            // array(new Exception('Exception 1'), new Exception('Exception 2')),
             // different types
             [new SampleClass(4, 8, 15), false],
             [false, new SampleClass(4, 8, 15)],
@@ -2290,7 +2372,7 @@ XML;
                 new DateTime('2013-03-29T04:13:35-0600'),
             ],
             // Exception
-            //array(new Exception('Exception 1'), new Exception('Exception 1')),
+            // array(new Exception('Exception 1'), new Exception('Exception 1')),
             // mixed types
             [0, '0'],
             ['0', 0],
