@@ -118,7 +118,7 @@ final class MetadataCollectionTest extends TestCase
             [
                 Metadata::coversOnClass(''),
                 Metadata::coversOnMethod(''),
-            ]
+            ],
         );
 
         $this->assertCount(2, $collection);
@@ -475,6 +475,14 @@ final class MetadataCollectionTest extends TestCase
         $this->assertTrue($collection->asArray()[0]->isUsesFunction());
     }
 
+    public function test_Can_be_filtered_for_WithoutErrorHandler(): void
+    {
+        $collection = $this->collectionWithOneOfEach()->isWithoutErrorHandler();
+
+        $this->assertCount(1, $collection);
+        $this->assertTrue($collection->asArray()[0]->isWithoutErrorHandler());
+    }
+
     private function collectionWithOneOfEach(): MetadataCollection
     {
         return MetadataCollection::fromArray(
@@ -511,14 +519,14 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::requiresPhpOnClass(
                     new ComparisonRequirement(
                         '8.0.0',
-                        new VersionComparisonOperator('>=')
-                    )
+                        new VersionComparisonOperator('>='),
+                    ),
                 ),
                 Metadata::requiresPhpunitOnClass(
                     new ComparisonRequirement(
                         '10.0.0',
-                        new VersionComparisonOperator('>=')
-                    )
+                        new VersionComparisonOperator('>='),
+                    ),
                 ),
                 Metadata::requiresSettingOnClass('foo', 'bar'),
                 Metadata::runClassInSeparateProcess(),
@@ -531,7 +539,8 @@ final class MetadataCollectionTest extends TestCase
                 Metadata::usesClass(''),
                 Metadata::usesDefaultClass(''),
                 Metadata::usesFunction(''),
-            ]
+                Metadata::withoutErrorHandler(),
+            ],
         );
     }
 }
