@@ -22,20 +22,13 @@ use PHPUnit\Event\Telemetry\MemoryUsage;
 use PHPUnit\Event\Telemetry\Snapshot;
 use PHPUnit\Event\Test\BeforeFirstTestMethodErrored;
 use PHPUnit\Event\Test\ConsideredRisky;
-use PHPUnit\Event\Test\DeprecationTriggered;
 use PHPUnit\Event\Test\Errored;
-use PHPUnit\Event\Test\ErrorTriggered;
 use PHPUnit\Event\Test\Failed;
 use PHPUnit\Event\Test\MarkedIncomplete;
-use PHPUnit\Event\Test\NoticeTriggered;
-use PHPUnit\Event\Test\PhpDeprecationTriggered;
-use PHPUnit\Event\Test\PhpNoticeTriggered;
 use PHPUnit\Event\Test\PhpunitDeprecationTriggered;
 use PHPUnit\Event\Test\PhpunitErrorTriggered;
 use PHPUnit\Event\Test\PhpunitWarningTriggered;
-use PHPUnit\Event\Test\PhpWarningTriggered;
 use PHPUnit\Event\Test\Skipped as TestSkipped;
-use PHPUnit\Event\Test\WarningTriggered;
 use PHPUnit\Event\TestData\TestDataCollection;
 use PHPUnit\Event\TestRunner\DeprecationTriggered as TestRunnerDeprecationTriggered;
 use PHPUnit\Event\TestRunner\WarningTriggered as TestRunnerWarningTriggered;
@@ -47,6 +40,7 @@ use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\IncompleteTestError;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\Metadata\MetadataCollection;
+use PHPUnit\TestRunner\TestResult\Issues\Issue;
 use PHPUnit\TestRunner\TestResult\TestResult;
 use PHPUnit\TextUI\Output\Printer;
 use PHPUnit\TextUI\Output\SummaryPrinter;
@@ -65,7 +59,7 @@ final class ResultPrinterTest extends TestCase
             'no tests' => [
                 __DIR__ . '/expectations/no_tests.txt',
                 self::createTestResult(
-                    numberOfTestsRun: 0
+                    numberOfTestsRun: 0,
                 ),
             ],
 
@@ -79,7 +73,7 @@ final class ResultPrinterTest extends TestCase
                 self::createTestResult(
                     testErroredEvents: [
                         self::erroredTest(),
-                    ]
+                    ],
                 ),
             ],
 
@@ -88,7 +82,7 @@ final class ResultPrinterTest extends TestCase
                 self::createTestResult(
                     testFailedEvents: [
                         self::failedTest(),
-                    ]
+                    ],
                 ),
             ],
 
@@ -99,9 +93,9 @@ final class ResultPrinterTest extends TestCase
                         new MarkedIncomplete(
                             self::telemetryInfo(),
                             self::testMethod(),
-                            ThrowableBuilder::from(new IncompleteTestError('message'))
+                            ThrowableBuilder::from(new IncompleteTestError('message')),
                         ),
-                    ]
+                    ],
                 ),
             ],
 
@@ -112,9 +106,9 @@ final class ResultPrinterTest extends TestCase
                         new TestSkipped(
                             self::telemetryInfo(),
                             self::testMethod(),
-                            'message'
+                            'message',
                         ),
-                    ]
+                    ],
                 ),
             ],
 
@@ -125,7 +119,7 @@ final class ResultPrinterTest extends TestCase
                         'Foo::testBar' => [
                             self::riskyTest('message'),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -137,7 +131,7 @@ final class ResultPrinterTest extends TestCase
                             self::riskyTest('message'),
                             self::riskyTest('message'),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -149,7 +143,7 @@ final class ResultPrinterTest extends TestCase
                             self::riskyTest("message\nmessage\nmessage"),
                             self::riskyTest("message\nmessage\nmessage"),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -163,7 +157,7 @@ final class ResultPrinterTest extends TestCase
                         'Foo::testBar' => [
                             self::riskyTest('message'),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -177,48 +171,48 @@ final class ResultPrinterTest extends TestCase
                         'Foo::testBar' => [
                             self::riskyTest('message'),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
             'successful test that triggers deprecation' => [
                 __DIR__ . '/expectations/successful_test_with_deprecation.txt',
                 self::createTestResult(
-                    testTriggeredDeprecationEvents: [
-                        'Foo::testBar' => [
-                            new DeprecationTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    deprecations: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
             'successful test that triggers PHP deprecation' => [
                 __DIR__ . '/expectations/successful_test_with_php_deprecation.txt',
                 self::createTestResult(
-                    testTriggeredPhpDeprecationEvents: [
-                        'Foo::testBar' => [
-                            new PhpDeprecationTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                            new PhpDeprecationTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'another message',
-                                'Foo.php',
-                                2
-                            ),
-                        ],
-                    ]
+                    phpDeprecations: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                        Issue::from(
+                            'Foo.php',
+                            2,
+                            'another message',
+                            self::testMethod(),
+                        ),
+                    ],
+                ),
+            ],
+
+            'successful test that triggers the same PHP deprecation multiple times' => [
+                __DIR__ . '/expectations/successful_test_with_php_deprecation_multiple.txt',
+                self::createTestResult(
+                    phpDeprecations: self::samePhpDeprecationsTriggeredTwice(),
                 ),
             ],
 
@@ -230,14 +224,14 @@ final class ResultPrinterTest extends TestCase
                             new PhpunitDeprecationTriggered(
                                 self::telemetryInfo(),
                                 self::testMethod(),
-                                'message'
+                                'message',
                             ),
                         ],
                     ],
                     testRunnerTriggeredDeprecationEvents: [
                         new TestRunnerDeprecationTriggered(
                             self::telemetryInfo(),
-                            'message'
+                            'message',
                         ),
                     ],
                 ),
@@ -246,85 +240,70 @@ final class ResultPrinterTest extends TestCase
             'successful test that triggers error' => [
                 __DIR__ . '/expectations/successful_test_with_error.txt',
                 self::createTestResult(
-                    testTriggeredErrorEvents: [
-                        'Foo::testBar' => [
-                            new ErrorTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    errors: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
             'successful test that triggers notice' => [
                 __DIR__ . '/expectations/successful_test_with_notice.txt',
                 self::createTestResult(
-                    testTriggeredNoticeEvents: [
-                        'Foo::testBar' => [
-                            new NoticeTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    notices: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
             'successful test that triggers PHP notice' => [
                 __DIR__ . '/expectations/successful_test_with_php_notice.txt',
                 self::createTestResult(
-                    testTriggeredPhpNoticeEvents: [
-                        'Foo::testBar' => [
-                            new PhpNoticeTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    phpNotices: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
             'successful test that triggers warning' => [
                 __DIR__ . '/expectations/successful_test_with_warning.txt',
                 self::createTestResult(
-                    testTriggeredWarningEvents: [
-                        'Foo::testBar' => [
-                            new WarningTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    warnings: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
             'successful test that triggers PHP warning' => [
                 __DIR__ . '/expectations/successful_test_with_php_warning.txt',
                 self::createTestResult(
-                    testTriggeredPhpWarningEvents: [
-                        'Foo::testBar' => [
-                            new PhpWarningTriggered(
-                                self::telemetryInfo(),
-                                self::testMethod(),
-                                'message',
-                                'Foo.php',
-                                1
-                            ),
-                        ],
-                    ]
+                    phpWarnings: [
+                        Issue::from(
+                            'Foo.php',
+                            1,
+                            'message',
+                            self::testMethod(),
+                        ),
+                    ],
                 ),
             ],
 
@@ -339,10 +318,10 @@ final class ResultPrinterTest extends TestCase
                             new PhpunitErrorTriggered(
                                 self::telemetryInfo(),
                                 self::testMethod(),
-                                'message'
+                                'message',
                             ),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -354,10 +333,10 @@ final class ResultPrinterTest extends TestCase
                             new PhpunitWarningTriggered(
                                 self::telemetryInfo(),
                                 self::testMethod(),
-                                'message'
+                                'message',
                             ),
                         ],
-                    ]
+                    ],
                 ),
             ],
 
@@ -391,7 +370,7 @@ final class ResultPrinterTest extends TestCase
 
         $summaryPrinter = new SummaryPrinter(
             $printer,
-            false
+            false,
         );
 
         $summaryPrinter->print($result);
@@ -399,7 +378,7 @@ final class ResultPrinterTest extends TestCase
         /* @noinspection PhpPossiblePolymorphicInvocationInspection */
         $this->assertStringMatchesFormatFile(
             $expectationFile,
-            $printer->buffer()
+            $printer->buffer(),
         );
     }
 
@@ -432,20 +411,20 @@ final class ResultPrinterTest extends TestCase
      * @psalm-param list<TestSuiteSkipped> $testSuiteSkippedEvents
      * @psalm-param list<TestSkipped> $testSkippedEvents
      * @psalm-param list<MarkedIncomplete> $testMarkedIncompleteEvents
-     * @psalm-param array<string,list<DeprecationTriggered>> $testTriggeredDeprecationEvents
-     * @psalm-param array<string,list<PhpDeprecationTriggered>> $testTriggeredPhpDeprecationEvents
+     * @psalm-param list<Issue> $deprecations
+     * @psalm-param list<Issue> $phpDeprecations
      * @psalm-param array<string,list<PhpunitDeprecationTriggered>> $testTriggeredPhpunitDeprecationEvents
-     * @psalm-param array<string,list<ErrorTriggered>> $testTriggeredErrorEvents
-     * @psalm-param array<string,list<NoticeTriggered>> $testTriggeredNoticeEvents
-     * @psalm-param array<string,list<PhpNoticeTriggered>> $testTriggeredPhpNoticeEvents
-     * @psalm-param array<string,list<WarningTriggered>> $testTriggeredWarningEvents
-     * @psalm-param array<string,list<PhpWarningTriggered>> $testTriggeredPhpWarningEvents
+     * @psalm-param list<Issue> $errors
+     * @psalm-param list<Issue> $notices
+     * @psalm-param list<Issue> $phpNotices
+     * @psalm-param list<Issue> $warnings
+     * @psalm-param list<Issue> $phpWarnings
      * @psalm-param array<string,list<PhpunitErrorTriggered>> $testTriggeredPhpunitErrorEvents
      * @psalm-param array<string,list<PhpunitWarningTriggered>> $testTriggeredPhpunitWarningEvents
      * @psalm-param list<TestRunnerDeprecationTriggered> $testRunnerTriggeredDeprecationEvents
      * @psalm-param list<TestRunnerWarningTriggered> $testRunnerTriggeredWarningEvents
      */
-    private static function createTestResult(int $numberOfTests = 1, int $numberOfTestsRun = 1, int $numberOfAssertions = 1, array $testErroredEvents = [], array $testFailedEvents = [], array $testConsideredRiskyEvents = [], array $testSuiteSkippedEvents = [], array $testSkippedEvents = [], array $testMarkedIncompleteEvents = [], array $testTriggeredDeprecationEvents = [], array $testTriggeredPhpDeprecationEvents = [], array $testTriggeredPhpunitDeprecationEvents = [], array $testTriggeredErrorEvents = [], array $testTriggeredNoticeEvents = [], array $testTriggeredPhpNoticeEvents = [], array $testTriggeredWarningEvents = [], array $testTriggeredPhpWarningEvents = [], array $testTriggeredPhpunitErrorEvents = [], array $testTriggeredPhpunitWarningEvents = [], array $testRunnerTriggeredDeprecationEvents = [], array $testRunnerTriggeredWarningEvents = []): TestResult
+    private static function createTestResult(int $numberOfTests = 1, int $numberOfTestsRun = 1, int $numberOfAssertions = 1, array $testErroredEvents = [], array $testFailedEvents = [], array $testConsideredRiskyEvents = [], array $testSuiteSkippedEvents = [], array $testSkippedEvents = [], array $testMarkedIncompleteEvents = [], array $deprecations = [], array $phpDeprecations = [], array $testTriggeredPhpunitDeprecationEvents = [], array $errors = [], array $notices = [], array $phpNotices = [], array $warnings = [], array $phpWarnings = [], array $testTriggeredPhpunitErrorEvents = [], array $testTriggeredPhpunitWarningEvents = [], array $testRunnerTriggeredDeprecationEvents = [], array $testRunnerTriggeredWarningEvents = []): TestResult
     {
         return new TestResult(
             $numberOfTests,
@@ -457,18 +436,18 @@ final class ResultPrinterTest extends TestCase
             $testSuiteSkippedEvents,
             $testSkippedEvents,
             $testMarkedIncompleteEvents,
-            $testTriggeredDeprecationEvents,
-            $testTriggeredPhpDeprecationEvents,
             $testTriggeredPhpunitDeprecationEvents,
-            $testTriggeredErrorEvents,
-            $testTriggeredNoticeEvents,
-            $testTriggeredPhpNoticeEvents,
-            $testTriggeredWarningEvents,
-            $testTriggeredPhpWarningEvents,
             $testTriggeredPhpunitErrorEvents,
             $testTriggeredPhpunitWarningEvents,
             $testRunnerTriggeredDeprecationEvents,
             $testRunnerTriggeredWarningEvents,
+            $errors,
+            $deprecations,
+            $notices,
+            $warnings,
+            $phpDeprecations,
+            $phpNotices,
+            $phpWarnings,
         );
     }
 
@@ -477,7 +456,7 @@ final class ResultPrinterTest extends TestCase
         return new Errored(
             self::telemetryInfo(),
             self::testMethod(),
-            ThrowableBuilder::from(new Exception('message'))
+            ThrowableBuilder::from(new Exception('message')),
         );
     }
 
@@ -488,10 +467,10 @@ final class ResultPrinterTest extends TestCase
             self::testMethod(),
             ThrowableBuilder::from(
                 new ExpectationFailedException(
-                    'Failed asserting that false is true.'
-                )
+                    'Failed asserting that false is true.',
+                ),
             ),
-            null
+            null,
         );
     }
 
@@ -500,7 +479,7 @@ final class ResultPrinterTest extends TestCase
         return new ConsideredRisky(
             self::telemetryInfo(),
             self::testMethod(),
-            $message
+            $message,
         );
     }
 
@@ -513,7 +492,7 @@ final class ResultPrinterTest extends TestCase
             1,
             TestDoxBuilder::fromClassNameAndMethodName('Foo', 'bar'),
             MetadataCollection::fromArray([]),
-            TestDataCollection::fromArray([])
+            TestDataCollection::fromArray([]),
         );
     }
 
@@ -524,7 +503,7 @@ final class ResultPrinterTest extends TestCase
                 HRTime::fromSecondsAndNanoseconds(...hrtime(false)),
                 MemoryUsage::fromBytes(1000),
                 MemoryUsage::fromBytes(2000),
-                new GarbageCollectorStatus(0, 0, 0, 0, false, false, false, 0)
+                new GarbageCollectorStatus(0, 0, 0, 0, 0.0, 0.0, 0.0, 0.0, false, false, false, 0),
             ),
             Duration::fromSecondsAndNanoseconds(123, 456),
             MemoryUsage::fromBytes(2000),
@@ -532,4 +511,18 @@ final class ResultPrinterTest extends TestCase
             MemoryUsage::fromBytes(3000),
         );
     }
+
+    private static function samePhpDeprecationsTriggeredTwice(): array
+    {
+        $issue = Issue::from(
+            'Foo.php',
+            1,
+            'message',
+            self::testMethod(),
+        );
+
+        $issue->triggeredBy(self::testMethod());
+
+        return [$issue];
+    }
 }
